utils

package
v1.7.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: GPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetPassphrase

func GetPassphrase(pwd string, pwdFilePath string) (string, error)

GetPassphrase fetches the correct passphrase depending on if a file is available to read from or if the user wants to enter in their own passphrase. Otherwise, just use the default passphrase. No confirmation of passphrase

func GetPassphraseWithConfirm

func GetPassphraseWithConfirm(pwd string, pwdFilePath string) (string, error)

GetPassphraseWithConfirm fetches the correct passphrase depending on if a file is available to read from or if the user wants to enter in their own passphrase. Otherwise, just use the default passphrase. Passphrase requires a confirmation

func GetURL

func GetURL(url string, target interface{}) error

GetURL provides json result decode to struct

func LoadKey

func LoadKey(pemFile string, skIndex int, converter core.PubkeyConverter, pwd string, pwdFilePath string) ([]byte, []byte, string, error)

func PostURL

func PostURL(url, body string, headers []string, target interface{}) error

PostURL provides a post using a json string

Types

This section is empty.

Jump to