Documentation
¶
Index ¶
- func GetPassphrase(pwd string, pwdFilePath string) (string, error)
- func GetPassphraseWithConfirm(pwd string, pwdFilePath string) (string, error)
- func GetURL(url string, target interface{}) error
- func LoadKey(pemFile string, skIndex int, converter core.PubkeyConverter, pwd string, ...) ([]byte, []byte, string, error)
- func PostURL(url, body string, headers []string, target interface{}) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetPassphrase ¶
GetPassphrase fetches the correct passphrase depending on if a file is available to read from or if the user wants to enter in their own passphrase. Otherwise, just use the default passphrase. No confirmation of passphrase
func GetPassphraseWithConfirm ¶
GetPassphraseWithConfirm fetches the correct passphrase depending on if a file is available to read from or if the user wants to enter in their own passphrase. Otherwise, just use the default passphrase. Passphrase requires a confirmation
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.